@@ -36,7 +36,6 @@
 struct _PhotosPipeline
 {
   GObject parent_instance;
-  GeglNode *parent;
   GHashTable *hash;
   GeglNode *graph;
   gchar *snapshot;
@@ -212,13 +211,9 @@ photos_pipeline_constructed (GObject *object)
 
   G_OBJECT_CLASS (photos_pipeline_parent_class)->constructed (object);
 
-  self->graph = gegl_node_new ();
-  gegl_node_add_child (self->parent, self->graph);
   input = gegl_node_get_input_proxy (self->graph, "input");
   output = gegl_node_get_output_proxy (self->graph, "output");
   gegl_node_link (input, output);
-
-  g_clear_object (&self->parent); /* We will not need it any more */
 }
 
 
@@ -237,7 +232,6 @@ photos_pipeline_dispose (GObject *object)
   g_clear_pointer (&self->hash, (GDestroyNotify) g_hash_table_unref);
 
   g_clear_object (&self->graph);
-  g_clear_object (&self->parent);
 
   G_OBJECT_CLASS (photos_pipeline_parent_class)->dispose (object);
 }
@@ -265,8 +259,13 @@ photos_pipeline_set_property (GObject *object, guint prop_id, const GValue *valu
   switch (prop_id)
     {
     case PROP_PARENT:
-      self->parent = GEGL_NODE (g_value_dup_object (value));
-      break;
+      {
+        GeglNode *parent;
+
+        parent = GEGL_NODE (g_value_get_object (value));
+        photos_pipeline_set_parent (self, parent);
+        break;
+      }
 
     case PROP_URI:
       self->uri = g_value_dup_string (value);
@@ -285,6 +284,7 @@ photos_pipeline_init (PhotosPipeline *self)
   EGG_COUNTER_INC (instances);
 
   self->hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
+  self->graph = gegl_node_new ();
 }
 
 
@@ -304,7 +304,7 @@ photos_pipeline_class_init (PhotosPipelineClass *class)
                                                         "GeglNode object",
                                                         "A GeglNode representing the parent graph",
                                                         GEGL_TYPE_NODE,
-                                                        G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
+                                                        G_PARAM_CONSTRUCT | G_PARAM_WRITABLE));
 
   g_object_class_install_property (object_class,
                                    PROP_URI,
@@ -421,6 +421,9 @@ photos_pipeline_new_async (GeglNode *parent,
                            GAsyncReadyCallback callback,
                            gpointer user_data)
 {
+  g_return_if_fail (parent == NULL || GEGL_IS_NODE (parent));
+  g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
+
   g_async_initable_new_async (PHOTOS_TYPE_PIPELINE,
                               G_PRIORITY_DEFAULT,
                               cancellable,
@@ -438,6 +441,8 @@ photos_pipeline_new_finish (GAsyncResult *res, GError **error)
   GObject *ret_val;
   GObject *source_object;
 
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
   source_object = g_async_result_get_source_object (res);
   ret_val = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), res, error);
   g_object_unref (source_object);
@@ -457,6 +462,9 @@ photos_pipeline_add_valist (PhotosPipeline *self,
   GeglNode *output;
   gchar *xml = NULL;
 
+  g_return_if_fail (PHOTOS_IS_PIPELINE (self));
+  g_return_if_fail (operation != NULL && operation[0] != '\0');
+
   input = gegl_node_get_input_proxy (self->graph, "input");
   output = gegl_node_get_output_proxy (self->graph, "output");
   last = gegl_node_get_producer (output, "input", NULL);
@@ -493,6 +501,7 @@ photos_pipeline_get (PhotosPipeline *self, const gchar *operation, const gchar *
   va_list ap;
 
   g_return_val_if_fail (PHOTOS_IS_PIPELINE (self), FALSE);
+  g_return_val_if_fail (operation != NULL && operation[0] != '\0', FALSE);
 
   va_start (ap, first_property_name);
   ret_val = photos_pipeline_get_valist (self, operation, first_property_name, ap);
@@ -511,6 +520,9 @@ photos_pipeline_get_valist (PhotosPipeline *self,
   GeglNode *node;
   gboolean ret_val = FALSE;
 
+  g_return_val_if_fail (PHOTOS_IS_PIPELINE (self), FALSE);
+  g_return_val_if_fail (operation != NULL && operation[0] != '\0', FALSE);
+
   node = GEGL_NODE (g_hash_table_lookup (self->hash, operation));
   if (node == NULL)
     goto out;
@@ -529,6 +541,7 @@ photos_pipeline_get_valist (PhotosPipeline *self,
 GeglNode *
 photos_pipeline_get_graph (PhotosPipeline *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_PIPELINE (self), NULL);
   return self->graph;
 }
 
@@ -538,6 +551,8 @@ photos_pipeline_get_output (PhotosPipeline *self)
 {
   GeglNode *output;
 
+  g_return_val_if_fail (PHOTOS_IS_PIPELINE (self), NULL);
+
   output = gegl_node_get_output_proxy (self->graph, "output");
   return output;
 }
@@ -550,6 +565,8 @@ photos_pipeline_is_edited (PhotosPipeline *self)
   GSList *l;
   guint n_operations = 0;
 
+  g_return_val_if_fail (PHOTOS_IS_PIPELINE (self), FALSE);
+
   children = gegl_node_get_children (self->graph);
   if (children == NULL)
     goto out;
@@ -591,6 +608,8 @@ photos_pipeline_new_processor (PhotosPipeline *self)
 {
   GeglProcessor *processor;
 
+  g_return_val_if_fail (PHOTOS_IS_PIPELINE (self), NULL);
+
   processor = gegl_node_new_processor (self->graph, NULL);
   return processor;
 }
@@ -607,6 +626,9 @@ photos_pipeline_save_async (PhotosPipeline *self,
   gchar *xml = NULL;
   gsize len;
 
+  g_return_if_fail (PHOTOS_IS_PIPELINE (self));
+  g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
+
   xml = gegl_node_to_xml_full (self->graph, self->graph, "/");
   g_return_if_fail (xml != NULL);
 
@@ -655,6 +677,9 @@ photos_pipeline_remove (PhotosPipeline *self, const gchar *operation)
   gboolean ret_val = FALSE;
   gchar *xml = NULL;
 
+  g_return_val_if_fail (PHOTOS_IS_PIPELINE (self), FALSE);
+  g_return_val_if_fail (operation != NULL && operation[0] != '\0', FALSE);
+
   node = GEGL_NODE (g_hash_table_lookup (self->hash, operation));
   if (node == NULL)
     goto out;
@@ -680,6 +705,7 @@ photos_pipeline_revert (PhotosPipeline *self)
 {
   gchar *xml;
 
+  g_return_if_fail (PHOTOS_IS_PIPELINE (self));
   g_return_if_fail (self->snapshot != NULL);
 
   if (!photos_pipeline_create_graph_from_xml (self, self->snapshot))
@@ -700,6 +726,8 @@ photos_pipeline_revert_to_original (PhotosPipeline *self)
   const gchar *empty_xml = "<?xml version='1.0' encoding='UTF-8'?><gegl></gegl>";
   gchar *xml;
 
+  g_return_if_fail (PHOTOS_IS_PIPELINE (self));
+
   if (!photos_pipeline_create_graph_from_xml (self, empty_xml))
     g_warning ("Unable to revert to original");
 
@@ -712,9 +740,31 @@ photos_pipeline_revert_to_original (PhotosPipeline *self)
 }
 
 
+void
+photos_pipeline_set_parent (PhotosPipeline *self, GeglNode *parent)
+{
+  GeglNode *old_parent;
+
+  g_return_if_fail (PHOTOS_IS_PIPELINE (self));
+  g_return_if_fail (parent == NULL || GEGL_IS_NODE (parent));
+
+  old_parent = gegl_node_get_parent (self->graph);
+  if (parent == old_parent)
+    return;
+
+  if (old_parent != NULL)
+    gegl_node_remove_child (old_parent, self->graph);
+
+  if (parent != NULL)
+    gegl_node_add_child (parent, self->graph);
+}
+
+
 void
 photos_pipeline_snapshot (PhotosPipeline *self)
 {
+  g_return_if_fail (PHOTOS_IS_PIPELINE (self));
+
   g_free (self->snapshot);
   self->snapshot = gegl_node_to_xml_full (self->graph, self->graph, "/");
   photos_debug (PHOTOS_DEBUG_GEGL, "Snapshot: %s", self->snapshot);
