@@ -25,6 +25,8 @@
 
 #include "config.h"
 
+#include <math.h>
+
 #include <glib.h>
 #include <gio/gio.h>
 #include <glib/gi18n.h>
@@ -39,11 +41,15 @@
 #include "photos-preview-view.h"
 #include "photos-search-context.h"
 #include "photos-tool.h"
+#include "photos-utils.h"
 
 
 struct _PhotosPreviewView
 {
   GtkBin parent_instance;
+  GAction *zoom_best_fit_action;
+  GAction *zoom_in_action;
+  GAction *zoom_out_action;
   GCancellable *cancellable;
   GeglNode *node;
   GtkWidget *overlay;
@@ -54,6 +60,10 @@ struct _PhotosPreviewView
   PhotosModeController *mode_cntrlr;
   PhotosPreviewNavButtons *nav_buttons;
   PhotosTool *current_tool;
+  gboolean grabbed;
+  gdouble event_x_last;
+  gdouble event_y_last;
+  gdouble zoom_best_fit;
 };
 
 struct _PhotosPreviewViewClass
@@ -71,48 +81,139 @@ enum
 G_DEFINE_TYPE (PhotosPreviewView, photos_preview_view, GTK_TYPE_BIN);
 
 
+static const gdouble ZOOM_FACTOR_1 = 2.8561;
+static const gdouble ZOOM_FACTOR_2 = 1.69;
+static const gdouble ZOOM_FACTOR_3 = 1.3;
+
+
 static GtkWidget *photos_preview_view_create_view_with_container (PhotosPreviewView *self);
 
 
-static gboolean
-photos_preview_view_button_press_event (PhotosPreviewView *self, GdkEvent *event)
+static GtkWidget *
+photos_preview_view_get_view_from_view_container (GtkWidget *view_container)
 {
+  GtkWidget *child;
+  GtkWidget *view;
+
+  child = gtk_bin_get_child (GTK_BIN (view_container));
+
+  if (GTK_IS_VIEWPORT (child))
+    view = gtk_bin_get_child (GTK_BIN (child));
+  else
+    view = child;
+
+  return view;
+}
+
+
+static gboolean
+photos_preview_view_button_press_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+  PhotosPreviewView *self = PHOTOS_PREVIEW_VIEW (user_data);
+  GtkWidget *current_view;
+  GtkWidget *current_view_container;
   gboolean ret_val = GDK_EVENT_PROPAGATE;
 
+  current_view_container = gtk_stack_get_visible_child (GTK_STACK (self->stack));
+  current_view = photos_preview_view_get_view_from_view_container (current_view_container);
+  g_return_val_if_fail (widget == current_view, GDK_EVENT_PROPAGATE);
+
   if (self->current_tool == NULL)
-    goto out;
-
-  switch (event->button.button)
     {
-    case 1:
-      ret_val = photos_tool_left_click_event (self->current_tool, &(event->button));
-      break;
+      switch (event->button.button)
+        {
+        case 1:
+          {
+            if (photos_utils_scrolled_window_can_scroll (GTK_SCROLLED_WINDOW (current_view_container)))
+              {
+                GdkCursor *cursor = NULL;
+                GdkDisplay *display;
+                GdkWindow *window;
 
-    default:
-      break;
+                window = gtk_widget_get_window (widget);
+                display = gdk_window_get_display (window);
+                cursor = gdk_cursor_new_for_display (display, GDK_FLEUR);
+                gdk_window_set_cursor (window, cursor);
+
+                self->grabbed = TRUE;
+                self->event_x_last = event->button.x;
+                self->event_y_last = event->button.y;
+
+                ret_val = GDK_EVENT_STOP;
+
+                g_object_unref (cursor);
+              }
+
+            break;
+          }
+
+        default:
+          break;
+        }
+    }
+  else
+    {
+      switch (event->button.button)
+        {
+        case 1:
+          ret_val = photos_tool_left_click_event (self->current_tool, &(event->button));
+          break;
+
+        default:
+          break;
+        }
     }
 
- out:
   return ret_val;
 }
 
 
 static gboolean
-photos_preview_view_button_release_event (PhotosPreviewView *self, GdkEvent *event)
+photos_preview_view_button_release_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
+  PhotosPreviewView *self = PHOTOS_PREVIEW_VIEW (user_data);
+  GtkWidget *current_view;
+  GtkWidget *current_view_container;
   gboolean ret_val = GDK_EVENT_PROPAGATE;
 
+  current_view_container = gtk_stack_get_visible_child (GTK_STACK (self->stack));
+  current_view = photos_preview_view_get_view_from_view_container (current_view_container);
+  g_return_val_if_fail (widget == current_view, GDK_EVENT_PROPAGATE);
+
   if (self->current_tool == NULL)
-    goto out;
-
-  switch (event->button.button)
     {
-    case 1:
-      ret_val = photos_tool_left_unclick_event (self->current_tool, &(event->button));
-      break;
+      if (!self->grabbed)
+        goto out;
 
-    default:
-      break;
+      switch (event->button.button)
+        {
+        case 1:
+          {
+            GdkWindow *window;
+
+            window = gtk_widget_get_window (widget);
+            gdk_window_set_cursor (window, NULL);
+            self->grabbed = FALSE;
+            self->event_x_last = -1.0;
+            self->event_y_last = -1.0;
+            break;
+          }
+
+        default:
+          break;
+        }
+    }
+  else
+    {
+      switch (event->button.button)
+        {
+        case 1:
+          ret_val = photos_tool_left_unclick_event (self->current_tool, &(event->button));
+          break;
+
+        default:
+          break;
+        }
     }
 
  out:
@@ -177,31 +278,102 @@ photos_preview_view_get_invisible_child (PhotosPreviewView *self)
 
 
 static gboolean
-photos_preview_view_motion_notify_event (PhotosPreviewView *self, GdkEvent *event)
+photos_preview_view_motion_notify_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
+  PhotosPreviewView *self = PHOTOS_PREVIEW_VIEW (user_data);
+  GtkWidget *current_view;
+  GtkWidget *current_view_container;
   gboolean ret_val = GDK_EVENT_PROPAGATE;
 
+  current_view_container = gtk_stack_get_visible_child (GTK_STACK (self->stack));
+  current_view = photos_preview_view_get_view_from_view_container (current_view_container);
+  g_return_val_if_fail (widget == current_view, GDK_EVENT_PROPAGATE);
+
   if (self->current_tool == NULL)
-    goto out;
+    {
+      if (self->grabbed)
+        {
+          gdouble delta_x;
+          gdouble delta_y;
 
-  ret_val = photos_tool_motion_event (self->current_tool, &(event->motion));
+          /* We are moving the content, not the view. Hence the
+           * deltas are inverted.
+           */
+          delta_x = self->event_x_last - event->motion.x;
+          delta_y = self->event_y_last - event->motion.y;
+
+          self->event_x_last = event->motion.x;
+          self->event_y_last = event->motion.y;
+
+          photos_utils_scrolled_window_scroll (GTK_SCROLLED_WINDOW (current_view_container), delta_x, delta_y);
+          ret_val = GDK_EVENT_STOP;
+        }
+    }
+  else
+    {
+      ret_val = photos_tool_motion_event (self->current_tool, &(event->motion));
+    }
 
- out:
   return ret_val;
 }
 
 
+static void
+photos_preview_view_update_zoom_best_fit (PhotosPreviewView *self, PhotosImageView *view)
+{
+  GtkWidget *current_view;
+  GtkWidget *current_view_container;
+  gdouble zoom;
+
+  current_view_container = gtk_stack_get_visible_child (GTK_STACK (self->stack));
+  current_view = photos_preview_view_get_view_from_view_container (current_view_container);
+  g_return_if_fail (view == PHOTOS_IMAGE_VIEW (current_view));
+
+  zoom = photos_image_view_get_zoom (view);
+  if (!photos_image_view_get_best_fit (view) || zoom == 0.0)
+    return;
+
+  self->zoom_best_fit = zoom;
+}
+
+
+static void
+photos_preview_view_notify_best_fit (GObject *object, GParamSpec *pspec, gpointer user_data)
+{
+  PhotosPreviewView *self = PHOTOS_PREVIEW_VIEW (user_data);
+  PhotosImageView *view = PHOTOS_IMAGE_VIEW (object);
+
+  photos_preview_view_update_zoom_best_fit (self, view);
+}
+
+
+static void
+photos_preview_view_notify_zoom (GObject *object, GParamSpec *pspec, gpointer user_data)
+{
+  PhotosPreviewView *self = PHOTOS_PREVIEW_VIEW (user_data);
+  PhotosImageView *view = PHOTOS_IMAGE_VIEW (object);
+
+  photos_preview_view_update_zoom_best_fit (self, view);
+}
+
+
 static void
 photos_preview_view_navigate (PhotosPreviewView *self, gint position)
 {
+  GeglNode *node;
   GtkWidget *current_view_container;
   GtkWidget *new_view_container;
+  GtkWidget *next_view;
   GtkWidget *next_view_container;
 
+  next_view_container = photos_preview_view_get_invisible_child (self);
+  next_view = photos_preview_view_get_view_from_view_container (next_view_container);
+  node = photos_image_view_get_node (PHOTOS_IMAGE_VIEW (next_view));
+  g_return_if_fail (node == NULL);
+
   current_view_container = gtk_stack_get_visible_child (GTK_STACK (self->stack));
   gtk_container_child_set (GTK_CONTAINER (self->stack), current_view_container, "position", position, NULL);
 
-  next_view_container = photos_preview_view_get_invisible_child (self);
   gtk_stack_set_visible_child (GTK_STACK (self->stack), next_view_container);
 
   gtk_container_remove (GTK_CONTAINER (self->stack), current_view_container);
@@ -225,6 +397,50 @@ photos_preview_view_navigate_previous (PhotosPreviewView *self)
 }
 
 
+static gboolean
+photos_preview_view_scroll_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+  PhotosPreviewView *self = PHOTOS_PREVIEW_VIEW (user_data);
+  GVariant *parameter = NULL;
+  GtkWidget *current_view;
+  GtkWidget *current_view_container;
+  gboolean ret_val = GDK_EVENT_PROPAGATE;
+  gdouble delta_abs;
+
+  current_view_container = gtk_stack_get_visible_child (GTK_STACK (self->stack));
+  current_view = photos_preview_view_get_view_from_view_container (current_view_container);
+  g_return_val_if_fail (widget == current_view, GDK_EVENT_PROPAGATE);
+
+  if ((event->scroll.state & GDK_SHIFT_MASK) != 0 || (event->scroll.state & GDK_CONTROL_MASK) != 0)
+    goto out;
+
+  delta_abs = fabs (event->scroll.delta_y);
+  parameter = g_variant_new_double (delta_abs);
+  parameter = g_variant_ref_sink (parameter);
+
+  if (event->scroll.delta_y < 0.0)
+    {
+      if (g_action_get_enabled (self->zoom_in_action))
+        {
+          g_action_activate (self->zoom_in_action, parameter);
+          ret_val = GDK_EVENT_STOP;
+        }
+    }
+  else
+    {
+      if (g_action_get_enabled (self->zoom_out_action))
+        {
+          g_action_activate (self->zoom_out_action, parameter);
+          ret_val = GDK_EVENT_STOP;
+        }
+    }
+
+ out:
+  g_clear_pointer (&parameter, (GDestroyNotify) g_variant_unref);
+  return ret_val;
+}
+
+
 static GtkWidget *
 photos_preview_view_create_view_with_container (PhotosPreviewView *self)
 {
@@ -239,14 +455,14 @@ photos_preview_view_create_view_with_container (PhotosPreviewView *self)
 
   view = photos_image_view_new ();
   gtk_container_add (GTK_CONTAINER (sw), view);
-  g_signal_connect_swapped (view, "button-press-event", G_CALLBACK (photos_preview_view_button_press_event), self);
-  g_signal_connect_swapped (view,
-                            "button-release-event",
-                            G_CALLBACK (photos_preview_view_button_release_event),
-                            self);
-  g_signal_connect_swapped (view, "motion-notify-event", G_CALLBACK (photos_preview_view_motion_notify_event), self);
+  g_signal_connect (view, "button-press-event", G_CALLBACK (photos_preview_view_button_press_event), self);
+  g_signal_connect (view, "button-release-event", G_CALLBACK (photos_preview_view_button_release_event), self);
   g_signal_connect_swapped (view, "draw-background", G_CALLBACK (photos_preview_view_draw_background), self);
   g_signal_connect_swapped (view, "draw-overlay", G_CALLBACK (photos_preview_view_draw_overlay), self);
+  g_signal_connect (view, "motion-notify-event", G_CALLBACK (photos_preview_view_motion_notify_event), self);
+  g_signal_connect (view, "notify::best-fit", G_CALLBACK (photos_preview_view_notify_best_fit), self);
+  g_signal_connect (view, "notify::zoom", G_CALLBACK (photos_preview_view_notify_zoom), self);
+  g_signal_connect (view, "scroll-event", G_CALLBACK (photos_preview_view_scroll_event), self);
 
   /* It has to be visible to become the visible child of self->stack. */
   gtk_widget_show_all (sw);
@@ -255,23 +471,6 @@ photos_preview_view_create_view_with_container (PhotosPreviewView *self)
 }
 
 
-static GtkWidget *
-photos_preview_view_get_view_from_view_container (GtkWidget *view_container)
-{
-  GtkWidget *child;
-  GtkWidget *view;
-
-  child = gtk_bin_get_child (GTK_BIN (view_container));
-
-  if (GTK_IS_VIEWPORT (child))
-    view = gtk_bin_get_child (GTK_BIN (child));
-  else
-    view = child;
-
-  return view;
-}
-
-
 static void
 photos_preview_view_process (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
@@ -627,6 +826,8 @@ photos_preview_view_window_mode_changed (PhotosPreviewView *self, PhotosWindowMo
     case PHOTOS_WINDOW_MODE_PREVIEW:
       gtk_revealer_set_reveal_child (GTK_REVEALER (self->revealer), FALSE);
       photos_edit_palette_hide_details (PHOTOS_EDIT_PALETTE (self->palette));
+      photos_preview_nav_buttons_set_auto_hide (self->nav_buttons, TRUE);
+      photos_preview_nav_buttons_set_show_navigation (self->nav_buttons, TRUE);
       photos_preview_nav_buttons_show (self->nav_buttons);
       break;
 
@@ -638,6 +839,109 @@ photos_preview_view_window_mode_changed (PhotosPreviewView *self, PhotosWindowMo
 }
 
 
+static void
+photos_preview_view_zoom_best_fit (PhotosPreviewView *self)
+{
+  GtkWidget *view;
+  GtkWidget *view_container;
+
+  view_container = gtk_stack_get_visible_child (GTK_STACK (self->stack));
+  view = photos_preview_view_get_view_from_view_container (view_container);
+  photos_image_view_set_best_fit (PHOTOS_IMAGE_VIEW (view), TRUE);
+  g_simple_action_set_enabled (G_SIMPLE_ACTION (self->zoom_best_fit_action), FALSE);
+  g_simple_action_set_enabled (G_SIMPLE_ACTION (self->zoom_out_action), FALSE);
+  photos_preview_nav_buttons_set_auto_hide (self->nav_buttons, TRUE);
+  photos_preview_nav_buttons_set_show_navigation (self->nav_buttons, TRUE);
+}
+
+
+static void
+photos_preview_view_zoom_in (PhotosPreviewView *self, GVariant *parameter)
+{
+  GtkWidget *view;
+  GtkWidget *view_container;
+  gboolean best_fit;
+  gdouble delta;
+  gdouble delta_abs;
+  gdouble zoom;
+  gdouble zoom_factor;
+  gdouble zoom_factor_for_delta;
+
+  g_return_if_fail (self->zoom_best_fit > 0.0);
+
+  delta = g_variant_get_double (parameter);
+  g_return_if_fail (photos_utils_equal_double (delta, -1.0) || delta >= 0.0);
+
+  view_container = gtk_stack_get_visible_child (GTK_STACK (self->stack));
+  view = photos_preview_view_get_view_from_view_container (view_container);
+
+  best_fit = photos_image_view_get_best_fit (PHOTOS_IMAGE_VIEW (view));
+
+  if (delta >= 0.0)
+    zoom_factor = best_fit ? ZOOM_FACTOR_2 : ZOOM_FACTOR_3;
+  else
+    zoom_factor = best_fit ? ZOOM_FACTOR_1 : ZOOM_FACTOR_2;
+
+  delta_abs = fabs (delta);
+  zoom_factor_for_delta = pow (zoom_factor, delta_abs);
+
+  zoom = photos_image_view_get_zoom (PHOTOS_IMAGE_VIEW (view));
+  zoom *= zoom_factor_for_delta;
+
+  photos_image_view_set_zoom (PHOTOS_IMAGE_VIEW (view), zoom);
+
+  g_simple_action_set_enabled (G_SIMPLE_ACTION (self->zoom_best_fit_action), TRUE);
+  g_simple_action_set_enabled (G_SIMPLE_ACTION (self->zoom_out_action), TRUE);
+  photos_preview_nav_buttons_set_auto_hide (self->nav_buttons, FALSE);
+  photos_preview_nav_buttons_set_show_navigation (self->nav_buttons, FALSE);
+}
+
+
+static void
+photos_preview_view_zoom_out (PhotosPreviewView *self, GVariant *parameter)
+{
+  GtkWidget *view;
+  GtkWidget *view_container;
+  gdouble delta;
+  gdouble delta_abs;
+  gdouble zoom;
+  gdouble zoom_factor;
+  gdouble zoom_factor_for_delta;
+
+  g_return_if_fail (self->zoom_best_fit > 0.0);
+
+  delta = g_variant_get_double (parameter);
+  g_return_if_fail (photos_utils_equal_double (delta, -1.0) || delta >= 0.0);
+
+  view_container = gtk_stack_get_visible_child (GTK_STACK (self->stack));
+  view = photos_preview_view_get_view_from_view_container (view_container);
+
+  if (delta >= 0.0)
+    zoom_factor = ZOOM_FACTOR_3;
+  else
+    zoom_factor = ZOOM_FACTOR_2;
+
+  delta_abs = fabs (delta);
+  zoom_factor_for_delta = pow (zoom_factor, delta_abs);
+
+  zoom = photos_image_view_get_zoom (PHOTOS_IMAGE_VIEW (view));
+  zoom /= zoom_factor_for_delta;
+
+  if (zoom < self->zoom_best_fit || photos_utils_equal_double (self->zoom_best_fit, zoom))
+    {
+      photos_image_view_set_best_fit (PHOTOS_IMAGE_VIEW (view), TRUE);
+      g_simple_action_set_enabled (G_SIMPLE_ACTION (self->zoom_best_fit_action), FALSE);
+      g_simple_action_set_enabled (G_SIMPLE_ACTION (self->zoom_out_action), FALSE);
+      photos_preview_nav_buttons_set_auto_hide (self->nav_buttons, TRUE);
+      photos_preview_nav_buttons_set_show_navigation (self->nav_buttons, TRUE);
+    }
+  else
+    {
+      photos_image_view_set_zoom (PHOTOS_IMAGE_VIEW (view), zoom);
+    }
+}
+
+
 static void
 photos_preview_view_dispose (GObject *object)
 {
@@ -792,6 +1096,30 @@ photos_preview_view_init (PhotosPreviewView *self)
 
   action = g_action_map_lookup_action (G_ACTION_MAP (app), "sharpen-current");
   g_signal_connect_object (action, "activate", G_CALLBACK (photos_preview_view_sharpen), self, G_CONNECT_SWAPPED);
+
+  self->zoom_best_fit_action = g_action_map_lookup_action (G_ACTION_MAP (app), "zoom-best-fit");
+  g_signal_connect_object (self->zoom_best_fit_action,
+                           "activate",
+                           G_CALLBACK (photos_preview_view_zoom_best_fit),
+                           self,
+                           G_CONNECT_SWAPPED);
+
+  self->zoom_in_action = g_action_map_lookup_action (G_ACTION_MAP (app), "zoom-in");
+  g_signal_connect_object (self->zoom_in_action,
+                           "activate",
+                           G_CALLBACK (photos_preview_view_zoom_in),
+                           self,
+                           G_CONNECT_SWAPPED);
+
+  self->zoom_out_action = g_action_map_lookup_action (G_ACTION_MAP (app), "zoom-out");
+  g_signal_connect_object (self->zoom_out_action,
+                           "activate",
+                           G_CALLBACK (photos_preview_view_zoom_out),
+                           self,
+                           G_CONNECT_SWAPPED);
+
+  self->event_x_last = -1.0;
+  self->event_y_last = -1.0;
 }
 
 
@@ -830,7 +1158,9 @@ photos_preview_view_set_mode (PhotosPreviewView *self, PhotosWindowMode old_mode
   g_return_if_fail (old_mode != PHOTOS_WINDOW_MODE_EDIT);
   g_return_if_fail (old_mode != PHOTOS_WINDOW_MODE_PREVIEW);
 
+  photos_preview_nav_buttons_set_auto_hide (self->nav_buttons, TRUE);
   photos_preview_nav_buttons_set_mode (self->nav_buttons, old_mode);
+  photos_preview_nav_buttons_set_show_navigation (self->nav_buttons, TRUE);
   photos_preview_nav_buttons_show (self->nav_buttons);
 }
 
@@ -844,6 +1174,7 @@ photos_preview_view_set_node (PhotosPreviewView *self, GeglNode *node)
     return;
 
   view_container = gtk_stack_get_visible_child (GTK_STACK (self->stack));
+  self->zoom_best_fit = 0.0;
   g_clear_object (&self->node);
 
   if (node == NULL)
