@@ -573,7 +573,7 @@ photos_thumbnailer_handle_cancel (PhotosThumbnailer *self,
       if (connection == connection_ongoing && (guint32) serial == serial_ongoing)
         {
           g_cancellable_cancel (cancellable);
-          photos_thumbnailer_dbus_complete_cancel (self->skeleton, invocation);
+          photos_thumbnailer_dbus_complete_generate_thumbnail (self->skeleton, invocation);
           goto out;
         }
     }
@@ -672,6 +672,8 @@ photos_thumbnailer_dbus_register (GApplication *application,
   GDBusAuthObserver *observer = NULL;
   gboolean ret_val = FALSE;
 
+  g_return_val_if_fail (self->skeleton == NULL, FALSE);
+
   if (!G_APPLICATION_CLASS (photos_thumbnailer_parent_class)->dbus_register (application,
                                                                              connection,
                                                                              object_path,
@@ -692,6 +694,16 @@ photos_thumbnailer_dbus_register (GApplication *application,
   if (self->connection == NULL)
     goto out;
 
+  self->skeleton = photos_thumbnailer_dbus_skeleton_new ();
+  g_signal_connect_swapped (self->skeleton,
+                            "handle-cancel",
+                            G_CALLBACK (photos_thumbnailer_handle_cancel),
+                            self);
+  g_signal_connect_swapped (self->skeleton,
+                            "handle-generate-thumbnail",
+                            G_CALLBACK (photos_thumbnailer_handle_generate_thumbnail),
+                            self);
+
   if (!g_dbus_interface_skeleton_export (G_DBUS_INTERFACE_SKELETON (self->skeleton),
                                          self->connection,
                                          THUMBNAILER_PATH,
@@ -756,7 +768,7 @@ photos_thumbnailer_startup (GApplication *application)
 
   G_APPLICATION_CLASS (photos_thumbnailer_parent_class)->startup (application);
 
-  photos_gegl_init ();
+  gegl_init (NULL, NULL);
 
   self->resource_gegl = photos_gegl_get_resource ();
   g_resources_register (self->resource_gegl);
@@ -770,8 +782,9 @@ photos_thumbnailer_dispose (GObject *object)
 {
   PhotosThumbnailer *self = PHOTOS_THUMBNAILER (object);
 
+  g_assert_null (self->skeleton);
+
   g_clear_object (&self->connection);
-  g_clear_object (&self->skeleton);
   g_clear_pointer (&self->cancellables, (GDestroyNotify) g_hash_table_unref);
   g_clear_pointer (&self->resource_gegl, (GDestroyNotify) g_resources_unregister);
 
@@ -799,17 +812,6 @@ photos_thumbnailer_init (PhotosThumbnailer *self)
   photos_gegl_ensure_builtins ();
 
   self->cancellables = g_hash_table_new_full (g_direct_hash, g_direct_equal, g_object_unref, g_object_unref);
-
-  self->skeleton = photos_thumbnailer_dbus_skeleton_new ();
-  g_signal_connect_swapped (self->skeleton,
-                            "handle-cancel",
-                            G_CALLBACK (photos_thumbnailer_handle_cancel),
-                            self);
-  g_signal_connect_swapped (self->skeleton,
-                            "handle-generate-thumbnail",
-                            G_CALLBACK (photos_thumbnailer_handle_generate_thumbnail),
-                            self);
-
   g_application_add_main_option_entries (G_APPLICATION (self), COMMAND_LINE_OPTIONS);
 }
 
